@@ -9,6 +9,7 @@ from datetime import datetime, timedelta
 from halo import Halo
 from typing import Optional, Dict
 from dateutil import parser
+from metricflow.cli.main import _print_issues
 
 from ..auth import TransformAuth
 from ..constants import (
@@ -266,7 +267,12 @@ class CLIContext(TransformAuth):
         return self.user_state.current_model
 
     def resolve_query_model_key(
-        self, config_dir: Optional[str] = None, force_commit: bool = True
+        self,
+        config_dir: Optional[str] = None,
+        force_commit: bool = True,
+        is_dbt_model: bool = False,
+        dbt_profile: Optional[str] = None,
+        dbt_target: Optional[str] = None,
     ) -> Optional[ModelKey]:
         """Resolve which model key to use for a given query or materialization.
 
@@ -307,8 +313,15 @@ class CLIContext(TransformAuth):
             else:
                 spinner = Halo(text="Parsing and uploading local configs…", spinner="dots")
                 spinner.start()
-                model_key = self.mql.commit_configs(config_dir)
-                spinner.succeed("🌱 Successfully parsed local configs")
+                model_key, results = self.mql.commit_configs(
+                    config_dir=config_dir, is_dbt_model=is_dbt_model, dbt_profile=dbt_profile, dbt_target=dbt_target
+                )
+                if not results.has_blocking_issues:
+                    spinner.succeed("🌱 Successfully parsed local configs")
+                else:
+                    spinner.succeed("🌱 Blocking issues found with local configs")
+                    _print_issues(results)
+                    exit(1)
 
             self.cli_state.set_config_value(PREV_MODEL_ID, str(model_key.id))
             self.cli_state.set_config_value(PREV_CONFIG_DIR_PATH, current_config_path)
