@@ -67,6 +67,57 @@ def async_options(function: Callable) -> Callable:
     return function
 
 
+def show_all_issues_option(function: Callable) -> Callable:
+    """Used for showing all issues (warnings, future-errors, and errors) instead of just errors"""
+    return click.option(
+        "--show-all", is_flag=True, default=False, help="If specified, prints warnings and future-errors"
+    )(function)
+
+
+def verbose_issues_option(function: Callable) -> Callable:
+    """Used for showing extra details issues might have that aren't shown by default"""
+    return click.option(
+        "--verbose-issues", is_flag=True, default=False, help="If specified, prints any extra details issues might have"
+    )(function)
+
+
+def dw_timeout_option(function: Callable) -> Callable:
+    """Used for timing out async dw validation results polling"""
+    return click.option(
+        "-t",
+        "--timeout",
+        type=int,
+        help="Sets the timeout in seconds to wait for individual data warehouse validations to finish. Defaults to None, meaning no timeout",
+    )(function)
+
+
+def dbt_project_option(function: Callable) -> Callable:
+    """Used specifying the config dir should be interpreted as a dbt project"""
+    return click.option(
+        "--dbt-project", is_flag=True, default=False, help="If specified, treats config directory as dbt project"
+    )(function)
+
+
+def dbt_profile_option(function: Callable) -> Callable:
+    """Used for specifying the the dbt profile that should be used with the dbt project"""
+    return click.option(
+        "--dbt-profile",
+        type=str,
+        required=False,
+        help="The dbt profile to use when using `--dbt-project`. Defaults to the profile specified in dbt_profile.yml",
+    )(function)
+
+
+def dbt_target_option(function: Callable) -> Callable:
+    """Used for specifying the the dbt profile target that should be used with the dbt project"""
+    return click.option(
+        "--dbt-target",
+        type=str,
+        required=False,
+        help="The dbt target to use when using `--dbt-target`. Defaults to the target specified in dbt profile defintion",
+    )(function)
+
+
 def config_validation_options(function: Callable) -> Callable:
     """Common options when validating or committing configs"""
     function = click.option(
@@ -76,6 +127,20 @@ def config_validation_options(function: Callable) -> Callable:
         default=os.getcwd(),
         help="Path to directory containing Transform yaml models",
     )(function)
+
+    function = click.option(
+        "--skip-dw",
+        is_flag=True,
+        default=False,
+        help="If specified, skips the data warehouse validations",
+    )(function)
+
+    function = show_all_issues_option(function)
+    function = verbose_issues_option(function)
+    function = dw_timeout_option(function)
+    function = dbt_project_option(function)
+    function = dbt_profile_option(function)
+    function = dbt_target_option(function)
     return function
 
 
@@ -88,6 +153,10 @@ def query_options(function: Callable) -> Callable:
         help="Path to directory containing Transform yaml models to execute query against",
     )(function)
 
+    function = dbt_project_option(function)
+    function = dbt_profile_option(function)
+    function = dbt_target_option(function)
+
     function = click.option(
         "--force-commit",
         required=False,
@@ -206,8 +275,9 @@ def metrics_and_dimensions_options(function: Callable) -> Callable:
     )(function)
     function = click.option(
         "--dimensions",
-        required=True,
+        required=False,
         multiple=True,
+        default=[],
         help="Dimensions to group by: syntax is --dimensions ds. Submit a list of metrics by providing multiple --dimensions flags.",
         callback=lambda ctx, param, value: __validate_and_normalize_query_inputs("--dimensions ", value),
     )(function)
