@@ -369,7 +369,7 @@ def query(
     detach: bool,
     timeout: int,
     metrics: List[str],
-    dimensions: List[str],
+    dimensions: List[str] = [],
     where: Optional[str] = None,
     time_constraint: Optional[str] = None,
     time_granularity: Optional[TimeGranularity] = None,
