@@ -214,11 +214,17 @@ class Metric:
 
     def input_metadata(self, metadata: Dict[str, Any]) -> None:  # type: ignore[misc]
         """Input additional backend metadata."""
-        self.description = metadata["description"]
+        if "protectedFields" in metadata:
+            if metadata["protectedFields"] is None:
+                self.description = "<access denied>"
+                self.value_format = "<access denied>"
+            else:
+                protected_fields = metadata["protectedFields"]
+                self.description = protected_fields["description"]
+                self.value_format = protected_fields["valueFormat"] if "valueFormat" in protected_fields else None
+                self.is_additive = protected_fields["isAdditive"] if "isAdditive" in protected_fields else None
         self.display_name = metadata["displayName"]
         self.tier = metadata["tier"]
-        self.value_format = metadata["valueFormat"] if "valueFormat" in metadata else None
-        self.is_additive = metadata["isAdditive"] if "isAdditive" in metadata else None
         self.team_owners = [TeamOwner.from_gql_dict(t["team"]) for t in metadata["teamOwners"]]
         self.user_owners = [UserOwner.from_gql_dict(u["user"]) for u in metadata["userOwners"]]
 
