@@ -44,7 +44,7 @@ class MQLClient:
     def create_query(  # noqa: D
         self,
         metrics: List[str],
-        dimensions: List[str],
+        dimensions: List[str] = [],
         model_key_id: Optional[int] = None,
         where: Optional[str] = None,
         time_constraint: Optional[str] = None,
@@ -98,7 +98,7 @@ class MQLClient:
     def query(  # noqa: D
         self,
         metrics: List[str],
-        dimensions: List[str],
+        dimensions: List[str] = [],
         model_key_id: Optional[int] = None,
         where: Optional[str] = None,
         time_constraint: Optional[str] = None,
@@ -141,7 +141,7 @@ class MQLClient:
     def query_safe(  # noqa: D
         self,
         metrics: List[str],
-        dimensions: List[str],
+        dimensions: List[str] = [],
         model_key_id: Optional[int] = None,
         where: Optional[str] = None,
         time_constraint: Optional[str] = None,
