@@ -1,5 +1,7 @@
 import os
 import time
+from pathlib import Path
+
 import git
 import hashlib
 
@@ -55,7 +57,7 @@ def directory_last_edited(config_dir: str) -> Optional[float]:
     """Returns the last time a file or folder was edited in the given directory. None if folder doesn't exist."""
     if not os.path.exists(config_dir):
         return None
-    last_edited = 0.0
+    last_edited = os.path.getmtime(config_dir)
     for path, folders, filenames in os.walk(config_dir):
         folders[:] = [folder for folder in folders if not folder.startswith(".")]
         for filename in filenames:
@@ -64,3 +66,9 @@ def directory_last_edited(config_dir: str) -> Optional[float]:
         for folder in folders:
             last_edited = max(last_edited, os.path.getmtime(os.path.join(path, folder)))
     return last_edited
+
+
+def get_cli_config_path() -> Path:
+    """Returns the path of the transform config directory."""
+    config_dir = os.getenv("TFD_CONFIG_DIR")
+    return Path(config_dir).resolve().absolute() if config_dir else Path.home() / ".transform"
